package cn.jlsxwkj.common.config;

import cn.jlsxwkj.common.utils.Log;
import cn.jlsxwkj.moudles.weather_demo.WeatherService;
import jakarta.annotation.Resource;
import org.springframework.ai.model.function.FunctionCallback;
import org.springframework.ai.model.function.FunctionCallbackWrapper;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.net.InetAddress;
import java.util.HashSet;
import java.util.Set;

/**
 * 函数回调.
 *
 * @author zh
 */
@Configuration
public class FunctionCallConfig {

    /**
     * 天气对象.
     */
    @Resource
    private WeatherService weatherService;

    /**
     * 函数回调集合.
     */
    public static final Set<String> TOOLS_FUNCTION = new HashSet<>();

    /**
     * 获取天气.
     *
     * @return 返回回调函数
     */
    @Bean
    public FunctionCallback getWeather() {
        try {
            InetAddress byName = InetAddress.getByName("www.baidu.com");
            TOOLS_FUNCTION.add("getWeather");
            int timeOut = 1000;
            if (byName.isReachable(timeOut)) {
                Log.info(this.getClass(), "互联网畅通");
                return FunctionCallbackWrapper.builder(weatherService)
                    .withName("getWeather")
                    .withDescription("获取提供位置天气信息")
                    .build();
            }
            Log.info(this.getClass(), "互联网阻塞");
        } catch (Exception e) {
            Log.info(this.getClass(), "未连接互联网");
        }
        return null;
    }
}
