package cn.jlsxwkj.common.filter;

import cn.hutool.json.JSONUtil;
import cn.jlsxwkj.common.R.ResponseError;
import cn.jlsxwkj.common.exception.TooManyRequestsException;
import io.github.bucket4j.Bucket;
import jakarta.annotation.Resource;
import jakarta.servlet.Filter;
import jakarta.servlet.FilterChain;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * 限流.
 *
 * @author zh
 */
@Component
public class RateLimiterFilter implements Filter {

    /**
     * 限流令牌桶.
     */
    @Resource
    private Bucket bucket;

    /**
     * @param request  ServletRequest
     * @param response ServletResponse
     * @param chain    FilterChain
     * @throws IOException      IOException
     * @throws ServletException ServletException
     */
    @Override
    public void doFilter(
        final ServletRequest request,
        final ServletResponse response,
        final FilterChain chain)
        throws IOException, ServletException {
        if (bucket.tryConsume(1)) {
            chain.doFilter(request, response);
        } else {
            ResponseError data = ResponseError.data(TooManyRequestsException.class.getName());
            data.setMessage("请求次数过多, 请稍后再试");
            data.setCode(HttpStatus.TEMPORARY_REDIRECT.value());

            HttpServletResponse rsp = (HttpServletResponse) response;
            rsp.setStatus(HttpStatus.TEMPORARY_REDIRECT.value());
            rsp.setCharacterEncoding("utf-8");
            rsp.getWriter().write(JSONUtil.toJsonStr(data));
        }

    }
}
