package cn.jlsxwkj.common.handler;

import cn.dev33.satoken.exception.SaTokenException;
import cn.jlsxwkj.common.R.ResponseError;
import cn.jlsxwkj.common.exception.CustomException;
import cn.jlsxwkj.common.exception.InsertFailException;
import cn.jlsxwkj.common.utils.Log;
import cn.jlsxwkj.moudles.log_error.LogErrorService;
import jakarta.annotation.Resource;
import org.springframework.web.ErrorResponse;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * 全局异常捕捉.
 *
 * @author zh
 */
@RestControllerAdvice
public class GlobalRestExceptionHandler {

    /**
     * log error 对象.
     */
    @Resource
    private LogErrorService logErrorService;

    /**
     * 捕捉全局异常.
     *
     * @param e 异常
     * @return 封装异常对象
     */
    @ExceptionHandler(Throwable.class)
    public ResponseError exception(final Throwable e) {

        ResponseError responseError =
            ResponseError.data(e.getClass().getName());

        if (e instanceof CustomException) {
            responseError.setMessage(e.getMessage());
        }
        if (e instanceof ErrorResponse) {
            responseError.setCode(((ErrorResponse) e).getStatusCode().value());
            responseError.setMessage(e.getMessage());
        }
        if (e instanceof SaTokenException) {
            responseError.setCode(((SaTokenException) e).getCode());
            responseError.setMessage("账户未登录");
        }

        Log.error(e.getClass(), "Code       ====> {}", responseError.getCode());
        Log.error(e.getClass(), "Exception  ====> {}", responseError.getException());
        Log.error(e.getClass(), "Message    ====> {}", responseError.getMessage());
        e.printStackTrace();

        try {
            logErrorService.insertOne(e);
        } catch (InsertFailException insertFailException) {
            insertFailException.printStackTrace();
        }

        return responseError;
    }
}
