package cn.jlsxwkj.common.handler;


import cn.jlsxwkj.common.R.ResponseError;
import cn.jlsxwkj.common.R.ResponseSucceed;
import cn.jlsxwkj.common.utils.Log;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.core.MethodParameter;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

import java.util.Arrays;

/**
 * ControllerAdvice 绑定的Controller包的权限定名 例如:com.dj.Controller.
 *
 * @author Joker DJ
 */
@ControllerAdvice(basePackages = "cn.jlsxwkj.moudles")
public class ResultResponseHandler implements ResponseBodyAdvice<Object> {

    /**
     * supports.
     *
     * @param methodParameter MethodParameter
     * @param aClass          HttpMessageConverter
     * @return boolean
     */
    @Override
    public boolean supports(
        @Nullable final MethodParameter methodParameter,
        @Nullable final Class<? extends HttpMessageConverter<?>> aClass) {
        return true;
    }

    /**
     * beforeBodyWrite.
     *
     * @param o                  Object
     * @param methodParameter    MethodParameter
     * @param mediaType          MediaType
     * @param aClass             HttpMessageConverter
     * @param serverHttpRequest  ServerHttpRequest
     * @param serverHttpResponse ServerHttpResponse
     * @return Object
     */
    @Override
    public Object beforeBodyWrite(
        @Nullable final Object o,
        @Nullable final MethodParameter methodParameter,
        @Nullable final MediaType mediaType,
        @Nullable final Class<? extends HttpMessageConverter<?>> aClass,
        @Nullable final ServerHttpRequest serverHttpRequest,
        @Nullable final ServerHttpResponse serverHttpResponse) {
        // 对请求的结果在这里统一返回和处理
        if (o instanceof ResponseError errorHandler) {
            // 1、如果返回的结果是一个异常的结果，就把异常返回的结构数据倒腾到R.fail里面即可
            return ResponseSucceed.data(errorHandler);
        }
        if (o instanceof String) {
            try {
                // 2、因为springmvc数据转换器对String是有特殊处理 StringHttpMessageConverter
                ObjectMapper objectMapper = new ObjectMapper();
                ResponseSucceed data = ResponseSucceed.data(o);
                return objectMapper.writeValueAsString(data);
            } catch (Exception e) {
                Log.error(e.getClass(), Arrays.toString(e.getStackTrace()));
            }
        }
        if (o == null) {
            return null;
        }
        return ResponseSucceed.data(o);
    }
}


