package cn.jlsxwkj.common.reader;

import cn.jlsxwkj.common.utils.SplitDocument;
import lombok.Data;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.parser.AutoDetectParser;
import org.apache.tika.parser.ParseContext;
import org.apache.tika.sax.BodyContentHandler;
import org.springframework.ai.document.Document;
import org.springframework.ai.document.DocumentReader;
import org.springframework.ai.reader.ExtractedTextFormatter;
import org.xml.sax.ContentHandler;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.List;

/**
 * 文档读取.
 *
 * @author zh
 */
@Data
public class ParagraphDocReader implements DocumentReader {

    /**
     * parser.
     */
    private final AutoDetectParser parser;
    /**
     * handler.
     */
    private final ContentHandler handler;
    /**
     * metadata.
     */
    private final Metadata metadata;
    /**
     * context.
     */
    private final ParseContext context;
    /**
     * 文件流.
     */
    private final InputStream inputStream;
    /**
     * 文件名.
     */
    private final String fileName;
    /**
     * 窗口大小.
     */
    private final int windowSize;
    /**
     * textFormatter.
     */
    private final ExtractedTextFormatter textFormatter;

    /**
     * doc reader.
     *
     * @param bytes 文件数据
     * @param name    文件名
     * @param size    窗口大小
     */
    public ParagraphDocReader(final byte[] bytes,
                              final String name,
                              final int size) {
        this.textFormatter = ExtractedTextFormatter.defaults();
        this.parser = new AutoDetectParser();
        this.handler = new BodyContentHandler(-1);
        this.metadata = new Metadata();
        this.context = new ParseContext();
        this.inputStream = new ByteArrayInputStream(bytes);
        this.windowSize = size;
        this.fileName = name;
    }

    /**
     * 获取文档.
     *
     * @return 返回文档列表
     */
    @Override
    public List<Document> get() {
        try {
            this.parser.parse(this.inputStream, this.handler, this.metadata, this.context);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return SplitDocument.splitStringToListDocument(this.handler.toString(), this.windowSize, this.fileName);
    }
}
