package cn.jlsxwkj.common.reader;

import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.jlsxwkj.common.utils.SplitDocument;
import lombok.Data;
import org.springframework.ai.document.Document;
import org.springframework.ai.document.DocumentReader;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * 图片读取.
 *
 * @author zh
 */
@Data
public class ParagraphOcrReader implements DocumentReader {
    /**
     * ocr 地址.
     */
    private final String cnocrUrl;
    /**
     * 文件.
     */
    private final byte[] bytes;
    /**
     * 文件编码.
     */
    private final Charset charset = StandardCharsets.UTF_8;
    /**
     * 窗口大小.
     */
    private final int windowSize;
    /**
     * 文件名.
     */
    private final String fileName;

    /**
     * ocr reader.
     *
     * @param file 文件
     * @param name 文件名
     * @param url  ocr 地址
     * @param ws   窗口大小
     */
    public ParagraphOcrReader(final byte[] file,
                              final String name,
                              final String url,
                              final int ws) {
        this.bytes = file;
        this.windowSize = ws;
        this.cnocrUrl = url;
        this.fileName = name;
    }

    /**
     * 获取文档.
     *
     * @return 返回文档列表
     */
    @Override
    public List<Document> get() {
        String image = HttpRequest.post(cnocrUrl).form("image", bytes, fileName).execute().body();
        StringBuilder sb = new StringBuilder();
        new JSONArray(new JSONObject(image).get("results")).forEach(x ->
            sb.append(new JSONObject(x).get("text")).append(" "));
        String document = sb.toString();
        return SplitDocument.splitStringToListDocument(document, this.windowSize, this.fileName);
    }
}
