package cn.jlsxwkj.common.reader;


import cn.jlsxwkj.common.utils.SplitDocument;
import lombok.Data;
import org.springframework.ai.document.Document;
import org.springframework.ai.document.DocumentReader;
import org.springframework.util.StreamUtils;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * 文本读取.
 *
 * @author zh
 */
@Data
public class ParagraphTextReader implements DocumentReader {

    /**
     * inputStream.
     */
    private final InputStream inputStream;
    /**
     * 文件编码.
     */
    private final Charset charset = StandardCharsets.UTF_8;
    /**
     * 窗口大小.
     */
    private final int windowSize;
    /**
     * 文件名.
     */
    private final String fileName;

    /**
     * text reader.
     *
     * @param file 文件
     * @param name 文件名
     * @param size 窗口大小
     */
    public ParagraphTextReader(final byte[] file,
                               final String name,
                               final int size) {
        this.inputStream = new ByteArrayInputStream(file);
        this.windowSize = size;
        this.fileName = name;
    }

    /**
     * 读取文本内容,并根据换行进行分段,采用窗口模式,窗口为段落的数量.
     *
     * @return 文档信息列表
     */
    @Override
    public List<Document> get() {
        String document = null;
        try {
            document = StreamUtils.copyToString(inputStream, this.charset);
        } catch (IOException e) {
            e.printStackTrace();
        }
        assert document != null;
        return SplitDocument.splitStringToListDocument(document, this.windowSize, this.fileName);
    }
}
