package cn.jlsxwkj.common.utils;

import cn.hutool.core.lang.Tuple;
import cn.jlsxwkj.common.reader.ParagraphDocReader;
import cn.jlsxwkj.common.reader.ParagraphOcrReader;
import cn.jlsxwkj.common.reader.ParagraphTextReader;

import java.util.HashMap;
import java.util.Map;

/**
 * 校验支持的文件类型并创建 reader.
 *
 * @author zh
 */
public class FileType {
    /**
     * 缓存池.
     */
    private static final Map<String, Tuple> TYPE = new HashMap<>();

    /**
     * 创建校验对象.
     *
     * @param bytes    文件
     * @param fileName 文件名
     * @param winSize  窗口大小
     * @param cnocrUrl ocr识别地址
     */
    public FileType(final byte[] bytes,
                    final String fileName,
                    final int winSize,
                    final String cnocrUrl) {
        TYPE.put("txt", new Tuple("文本", new ParagraphTextReader(bytes, fileName, winSize)));
        TYPE.put("doc docx", new Tuple("文档", new ParagraphDocReader(bytes, fileName, winSize)));
        TYPE.put("jpg png", new Tuple("图片", new ParagraphOcrReader(bytes, fileName, cnocrUrl, winSize)));
    }

    /**
     * 判断文件是否支持.
     *
     * @param fileType 文件类型
     * @return 返回存在的对象
     */
    public Tuple getFileTypeAndResource(final String fileType) {
        for (String s : TYPE.keySet()) {
            if (s.contains(fileType)) {
                return TYPE.get(s);
            }
        }
        return null;
    }
}
