package cn.jlsxwkj.common.utils;

import cn.hutool.log.dialect.slf4j.Slf4jLog;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 打印日志对象缓存池.
 *
 * @author zh
 */
public final class Log {
    private Log() {
    }

    /**
     * Log 对象池.
     */
    private static final Map<String, Slf4jLog> CACHE_LOGS = new ConcurrentHashMap<>();

    /**
     * 打印 info 级别的日志.
     *
     * @param clazz  需要打印的对象类
     * @param format 格式化或需要打印的字符串
     * @param args   格式化字符串需要的参数
     */
    public static void info(final Class<?> clazz,
                            final String format,
                            final Object... args) {
        Slf4jLog log = getLogObj(clazz);
        log.info(format, args);
    }

    /**
     * 打印 warn 级别的日志.
     *
     * @param clazz  需要打印的对象类
     * @param format 格式化或需要打印的字符串
     * @param args   格式化字符串需要的参数
     */
    public static void warn(final Class<?> clazz,
                            final String format,
                            final Object... args) {
        Slf4jLog log = getLogObj(clazz);
        log.warn(format, args);
    }

    /**
     * 打印 error 级别的日志.
     *
     * @param clazz  需要打印的对象类
     * @param format 格式化或需要打印的字符串
     * @param args   格式化字符串需要的参数
     */
    public static void error(final Class<?> clazz,
                             final String format,
                             final Object... args) {
        Slf4jLog log = getLogObj(clazz);
        log.error(format, args);
    }

    /**
     * 获取或创建 log 对象.
     *
     * @param clazz 需要打印的对象类
     * @return 返回 log 对象
     */
    private static Slf4jLog getLogObj(final Class<?> clazz) {
        if (!CACHE_LOGS.containsKey(clazz.getName())) {
            CACHE_LOGS.put(clazz.getName(), new Slf4jLog(clazz));
        }
        return CACHE_LOGS.get(clazz.getName());
    }
}
