package cn.jlsxwkj.moudles.chat;

import cn.dev33.satoken.annotation.SaIgnore;
import cn.jlsxwkj.common.exception.CustomException;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import reactor.core.publisher.Flux;

/**
 * @author zh
 */
@RestController
@RequestMapping("/ai/rag/")
@Tag(name = "RAG chat")
public class ChatController {

    /**
     * chat 服务.
     */
    @Resource
    private ChatService chatService;

    /**
     * 上传文档.
     *
     * @param file 文件
     * @return 上传成功
     * @throws CustomException 上传失败异常
     */
    @PostMapping("/upload")
    @SaIgnore
    public String uploadDoc(
        @RequestBody final MultipartFile file) throws CustomException {
        return chatService.uploadDocument(file);
    }

    /**
     * 关键词搜索.
     *
     * @param keyword 关键词
     * @return 结果
     */
    @PostMapping("/search")
    public String searchDoc(@RequestParam final String keyword) {
        return chatService.search(keyword);
    }

    /**
     * 问答文档流.
     *
     * @param message 消息
     * @return 流消息
     */
    @PostMapping(value = "/chatStream",
        produces = {MediaType.TEXT_EVENT_STREAM_VALUE})
    public Flux<String> chatStream(@RequestParam final String message) {
        return chatService.chatStream(message);
    }

    /**
     * 问答文档总结流.
     *
     * @param message 消息
     * @param file    文件
     * @return 流消息
     */
    @PostMapping(value = "/chatSummaryStream",
        produces = {MediaType.TEXT_EVENT_STREAM_VALUE})
    public Flux<String> chatSummaryStream(
        @RequestParam(defaultValue = "帮我总结一下上面内容") final String message,
        @RequestBody final MultipartFile file) {
        return chatService.chatSummaryStream(message, file);
    }
}
